using System.Diagnostics;
using InfiniTec.Exchange.WebDav;

namespace InfiniTec.Exchange
{
    /// <summary>
    /// This class provides access to the body of a message.
    /// </summary>
    public class Body
    {
        private Item _Item;

        /// <summary>
        /// Gets or sets the text content.
        /// </summary>
        /// <value>The text content.</value>
        public string TextContent
        {
            [DebuggerStepThrough]
            get { return _Item.GetPropertyValue<string>(WellknownProperties.Item.TextBody); }
            [DebuggerStepThrough]
            set { _Item.SetPropertyValue<string>(WellknownProperties.Item.TextBody, value); }
        }

        /// <summary>
        /// Gets or sets the HTML content.
        /// </summary>
        /// <value>The HTML content.</value>
        public string HtmlContent
        {
            [DebuggerStepThrough]
            get { return _Item.GetPropertyValue<string>(WellknownProperties.Item.HtmlBody); }
            [DebuggerStepThrough]
            set { _Item.SetPropertyValue<string>(WellknownProperties.Item.HtmlBody, value); }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="Body"/> class.
        /// </summary>
        /// <param name="item">The item.</param>
        internal Body(Item item)
        {
            _Item = item;
        }
    }
}