using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Diagnostics;

namespace InfiniTec.Exchange
{
    internal class ChangeNotifyCollection<T> : Collection<T>
    {
        private bool _HasChanged;

        public bool HasChanged
        {
            [DebuggerStepThrough]
            get { return _HasChanged; }
        }

        public void AddRange(IEnumerable<T> items)
        {
            foreach (T item in items)
            {
                Add(item);
            }
        }

        public void ResetChanged()
        {
            _HasChanged = false;
        }

        protected override void ClearItems()
        {
            base.ClearItems();
            _HasChanged = true;
        }

        protected override void InsertItem(int index, T item)
        {
            base.InsertItem(index, item);
            _HasChanged = true;
        }

        protected override void RemoveItem(int index)
        {
            base.RemoveItem(index);
            _HasChanged = true;
        }

        protected override void SetItem(int index, T item)
        {
            base.SetItem(index, item);
            _HasChanged = true;
        }
    }
}