using System;
using System.Collections.Generic;
using System.ComponentModel;
using InfiniTec.DirectoryServices;
using InfiniTec.Threading;

namespace InfiniTec.Exchange
{
    /// <summary>
    /// Provides access to the various proerties of an Active Directory contact.
    /// </summary>
    public class Contact : IAddressListEntry
    {
        private ActiveDirectoryContact _BaseItem;

        /// <summary>
        /// Initializes a new instance of the <see cref="Contact"/> class.
        /// </summary>
        /// <param name="baseItem">The base item.</param>
        internal Contact(ActiveDirectoryContact baseItem)
        {
            _BaseItem = baseItem;
        }

        /// <summary>
        /// Gets or sets the country.
        /// </summary>
        /// <value>The country.</value>
        public string Country
        {
            get { return _BaseItem.Country; }
            set { _BaseItem.Country = value; }
        }

        /// <summary>
        /// Gets or sets the company.
        /// </summary>
        /// <value>The company.</value>
        public string Company
        {
            get { return _BaseItem.Company; }
            set { _BaseItem.Company = value; }
        }

        /// <summary>
        /// Gets or sets the department.
        /// </summary>
        /// <value>The department.</value>
        public string Department
        {
            get { return _BaseItem.Department; }
            set { _BaseItem.Department = value; }
        }

        /// <summary>
        /// Gets or sets the description.
        /// </summary>
        /// <value>The description.</value>
        public string Description
        {
            get { return _BaseItem.Description; }
            set { _BaseItem.Description = value; }
        }

        /// <summary>
        /// Gets or sets the fax number.
        /// </summary>
        /// <value>The fax number.</value>
        public string FaxNumber
        {
            get { return _BaseItem.FaxNumber; }
            set { _BaseItem.FaxNumber = value; }
        }

        /// <summary>
        /// Gets or sets the first name.
        /// </summary>
        /// <value>The name of the first.</value>
        public string FirstName
        {
            get { return _BaseItem.FirstName; }
            set { _BaseItem.FirstName = value; }
        }

        /// <summary>
        /// Gets or sets the home phone.
        /// </summary>
        /// <value>The home phone.</value>
        public string HomePhone
        {
            get { return _BaseItem.HomePhone; }
            set { _BaseItem.HomePhone = value; }
        }

        /// <summary>
        /// Gets or sets the initials.
        /// </summary>
        /// <value>The initials.</value>
        public string Initials
        {
            get { return _BaseItem.Initials; }
            set { _BaseItem.Initials = value; }
        }

        /// <summary>
        /// Gets or sets the IP phone.
        /// </summary>
        /// <value>The IP phone.</value>
        public string IPPhone
        {
            get { return _BaseItem.IPPhone; }
            set { _BaseItem.IPPhone = value; }
        }

        /// <summary>
        /// Gets or sets the city.
        /// </summary>
        /// <value>The city.</value>
        public string City
        {
            get { return _BaseItem.City; }
            set { _BaseItem.City = value; }
        }

        /// <summary>
        /// Gets or sets the mail address.
        /// </summary>
        /// <value>The mail address.</value>
        public string MailAddress
        {
            get { return _BaseItem.MailAddress; }
            set { _BaseItem.MailAddress = value; }
        }

        /// <summary>
        /// Gets or sets the mobile phone.
        /// </summary>
        /// <value>The mobile phone.</value>
        public string MobilePhone
        {
            get { return _BaseItem.MobilePhone; }
            set { _BaseItem.MobilePhone = value; }
        }

        /// <summary>
        /// Gets the other fax numbers.
        /// </summary>
        /// <value>The other fax numbers.</value>
        public IList<string> OtherFaxNumbers
        {
            get { return _BaseItem.OtherFaxNumbers; }
        }

        /// <summary>
        /// Gets the other home numbers.
        /// </summary>
        /// <value>The other home numbers.</value>
        public IList<string> OtherHomeNumbers
        {
            get { return _BaseItem.OtherHomeNumbers; }
        }

        /// <summary>
        /// Gets the other IP phone numbers.
        /// </summary>
        /// <value>The other IP phone numbers.</value>
        public IList<string> OtherIPPhoneNumbers
        {
            get { return _BaseItem.OtherIPPhoneNumbers; }
        }

        /// <summary>
        /// Gets the other mobile phone numbers.
        /// </summary>
        /// <value>The other mobile phone numbers.</value>
        public IList<string> OtherMobilePhoneNumbers
        {
            get { return _BaseItem.OtherMobilePhoneNumbers; }
        }

        /// <summary>
        /// Gets the other pager numbers.
        /// </summary>
        /// <value>The other pager numbers.</value>
        public IList<string> OtherPagerNumbers
        {
            get { return _BaseItem.OtherPagerNumbers; }
        }

        /// <summary>
        /// Gets the other telephone numbers.
        /// </summary>
        /// <value>The other telephone numbers.</value>
        public IList<string> OtherTelephoneNumbers
        {
            get { return _BaseItem.OtherTelephoneNumbers; }
        }

        /// <summary>
        /// Gets or sets the pager number.
        /// </summary>
        /// <value>The pager number.</value>
        public string PagerNumber
        {
            get { return _BaseItem.PagerNumber; }
            set { _BaseItem.PagerNumber = value; }
        }

        /// <summary>
        /// Gets or sets the office.
        /// </summary>
        /// <value>The office.</value>
        public string Office
        {
            get { return _BaseItem.Office; }
            set { _BaseItem.Office = value; }
        }

        /// <summary>
        /// Gets or sets the postal code.
        /// </summary>
        /// <value>The postal code.</value>
        public string PostalCode
        {
            get { return _BaseItem.PostalCode; }
            set { _BaseItem.PostalCode = value; }
        }

        /// <summary>
        /// Gets or sets the last name
        /// </summary>
        /// <value>The name of the last.</value>
        public string LastName
        {
            get { return _BaseItem.LastName; }
            set { _BaseItem.LastName = value; }
        }

        /// <summary>
        /// Gets or sets the post office box.
        /// </summary>
        /// <value>The post office box.</value>
        public string PostOfficeBox
        {
            get { return _BaseItem.PostOfficeBox; }
            set { _BaseItem.PostOfficeBox = value; }
        }

        /// <summary>
        /// Gets or sets the state.
        /// </summary>
        /// <value>The state.</value>
        public string State
        {
            get { return _BaseItem.State; }
            set { _BaseItem.State = value; }
        }

        /// <summary>
        /// Gets or sets the street address.
        /// </summary>
        /// <value>The street address.</value>
        public string StreetAddress
        {
            get { return _BaseItem.StreetAddress; }
            set { _BaseItem.StreetAddress = value; }
        }

        /// <summary>
        /// Gets or sets the telephone number.
        /// </summary>
        /// <value>The telephone number.</value>
        public string TelephoneNumber
        {
            get { return _BaseItem.TelephoneNumber; }
            set { _BaseItem.TelephoneNumber = value; }
        }

        /// <summary>
        /// Gets or sets the title.
        /// </summary>
        /// <value>The title.</value>
        public string Title
        {
            get { return _BaseItem.Title; }
            set { _BaseItem.Title = value; }
        }

        /// <summary>
        /// Gets or sets the other web page.
        /// </summary>
        /// <value>The other web page.</value>
        public string OtherWebPage
        {
            get { return _BaseItem.OtherWebPage; }
            set { _BaseItem.OtherWebPage = value; }
        }

        /// <summary>
        /// Gets or sets the user principal name.
        /// </summary>
        /// <value>The name of the user principal.</value>
        public string UserPrincipalName
        {
            get { return _BaseItem.UserPrincipalName; }
            set { _BaseItem.UserPrincipalName = value; }
        }

        /// <summary>
        /// Gets or sets the web page.
        /// </summary>
        /// <value>The web page.</value>
        public string WebPage
        {
            get { return _BaseItem.WebPage; }
            set { _BaseItem.WebPage = value; }
        }

        /// <summary>
        /// Gets the async operation operation used to refresh the item.
        /// </summary>
        /// <returns>An async operation which can be used to refresh the item.</returns>
        public AsyncOperation<RequestProgress> GetRefreshOperation()
        {
            return _BaseItem.GetRefreshOperation();
        }

        /// <summary>
        /// Synchronously refreshes the properties of the curren item.
        /// </summary>
        public void Refresh()
        {
            _BaseItem.Refresh();
        }

        /// <summary>
        /// Asynchronously refreshes the properties of the curren item.
        /// </summary>
        public void RefreshAsync()
        {
            _BaseItem.RefreshAsync();
        }

        /// <summary>
        /// This event is triggered, when a refresh operation completes.
        /// </summary>
        public event AsyncCompletedEventHandler RefreshCompleted
        {
            add { _BaseItem.RefreshCompleted += value; }
            remove { _BaseItem.RefreshCompleted -= value; }
        }

        /// <summary>
        /// Gets or sets the displayname of the item.
        /// </summary>
        /// <value>The displayname of the item.</value>
        public string DisplayName
        {
            get { return _BaseItem.DisplayName; }
            set { _BaseItem.DisplayName = value; }
        }

        /// <summary>
        /// Gets the name.
        /// </summary>
        /// <value>The name.</value>
        string IAddressListEntry.Name
        {
            get { return _BaseItem.DisplayName; }
        }
    }
}