namespace InfiniTec.Exchange
{
    /// <summary>
    /// Encapsulates a username/password combination and the <see cref="AuthenticationType"/> to use.
    /// </summary>
    public class Credential
    {
        private string _Username;
        private string _Password;
        private AuthenticationType _AuthenticationType;

        /// <summary>
        /// Gets or sets the username.
        /// </summary>
        /// <remarks>If set to null, integrated authentication is used.</remarks>
        public string Username
        {
            get { return _Username; }
            set { _Username = value; }
        }

        /// <summary>
        /// Gets or sets the Password.
        /// </summary>
        public string Password
        {
            get { return _Password; }
            set { _Password = value; }
        }

        /// <summary>
        /// Gets or sets the <see cref="AuthenticationType"/>.
        /// </summary>
        public AuthenticationType AuthenticationType
        {
            get { return _AuthenticationType; }
            set { _AuthenticationType = value; }
        }

        /// <summary>
        /// Creates a new instance of this class which is configured
        /// for integrated authentication.
        /// </summary>
        public Credential() : this(null, null, AuthenticationType.Ntlm)
        {
        }

        /// <summary>
        /// Creates a new instance of this class.
        /// </summary>
        /// <param name="username">The username to use.</param>
        /// <param name="password">The password to use.</param>
        /// <param name="authenticationType">The <see cref="AuthenticationType"/> to use.</param>
        public Credential(string username, string password, AuthenticationType authenticationType)
        {
            _Username = (username != null) ? username : "";
            _Password = (password != null) ? password : "";
            _AuthenticationType = authenticationType;
        }
    }
}