namespace InfiniTec.Exchange
{
    /// <summary>
    /// This class contains some constants of commonly used
    /// WebDAV and Exchange namespaces.
    /// </summary>
    public static class Namespaces
    {
        /// <summary>
        /// The DAV: namespace.
        /// </summary>
        public const string Dav = "DAV:";

        /// <summary>
        /// The "http://schemas.microsoft.com/exchange/" namespace.
        /// </summary>
        public const string Exchange = "http://schemas.microsoft.com/exchange/";

        /// <summary>
        /// The namespace for data type definitions.
        /// </summary>
        public const string DataType = "urn:uuid:c2f41010-65b3-11d1-a29f-00aa00c14882/";

        /// <summary>
        /// The default xml namespace.
        /// </summary>
        public const string Xml = "xml:";

        /// <summary>
        /// Namespace for exchange events.
        /// </summary>
        public const string ExchangeEvents = "http://schemas.microsoft.com/exchange/events/";

        /// <summary>
        /// Namespace for WebDAV replication settings.
        /// </summary>
        public const string WebDavReplication = "http://schemas.microsoft.com/repl/";

        /// <summary>
        /// Namespace for Exchange security settings, like XML Security descriptors.
        /// </summary>
        public const string ExchangeSecurity = "http://schemas.microsoft.com/exchange/security/";

        /// <summary>
        /// One of the namespaces for MAPI properties.
        /// </summary>
        public const string Mapi = "http://schemas.microsoft.com/mapi/";

        /// <summary>
        /// The http://schemas.microsoft.com/mapi/proptag/ namespace.
        /// </summary>
        public const string MapiPropTag = "http://schemas.microsoft.com/mapi/proptag/";

        /// <summary>
        /// Namespace for calendar properties.
        /// </summary>
        public const string Calendar = "urn:schemas:calendar:";

        /// <summary>
        /// Namespace for contacts properties.
        /// </summary>
        public const string Contacts = "urn:schemas:contacts:";

        /// <summary>
        /// Namespace for some of the mail properties.
        /// </summary>
        public const string HttpMail = "urn:schemas:httpmail:";

        /// <summary>
        /// Namespace for mail header properties.
        /// </summary>
        public const string MailHeader = "urn:schemas:mailheader:";

        /// <summary>
        /// This class defines the namespaces of common MAPI property sets
        /// </summary>
        public static class PropertySets
        {
            /// <summary>
            /// This namespace defines properties common to all exchange items.
            /// </summary>
            public const string Common = "http://schemas.microsoft.com/mapi/id/{00062008-0000-0000-C000-000000000046}/";

            /// <summary>
            /// This namespace defines properties used for task items.
            /// </summary>
            public const string Tasks = "http://schemas.microsoft.com/mapi/id/{00062003-0000-0000-C000-000000000046}/";

            /// <summary>
            /// This namespace defines properties used on contact items.
            /// </summary>
            public const string Address = "http://schemas.microsoft.com/mapi/id/{00062004-0000-0000-C000-000000000046}/";

            /// <summary>
            /// This namesspace defines properties used on appointment items.
            /// </summary>
            public const string Appointment =
                "http://schemas.microsoft.com/mapi/id/{00062002-0000-0000-C000-000000000046}/";

            /// <summary>
            /// This namespace defines properties used on meeting items.
            /// </summary>
            public const string Meeting = "http://schemas.microsoft.com/mapi/id/{6ED8DA90-450B-101B-98DA-00AA003F1305}/";
        }
    }
}