using System;
using System.Runtime.Serialization;

namespace InfiniTec.Exchange
{
    /// <summary>
    /// Exception thrown when a property of an object is accessed, but the instance
    /// has not been initialized.
    /// </summary>
    [Serializable]
    public sealed class NotInitializedException : Exception
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="NotInitializedException"/> class.
        /// </summary>
        public NotInitializedException()
        {
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="NotInitializedException"/> class.
        /// </summary>
        /// <param name="message">The message.</param>
        public NotInitializedException(string message) : base(message)
        {
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="NotInitializedException"/> class.
        /// </summary>
        /// <param name="message">The message.</param>
        /// <param name="innerException">The inner exception.</param>
        public NotInitializedException(string message, Exception innerException) : base(message, innerException)
        {
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="NotInitializedException"/> class.
        /// </summary>
        /// <param name="context">The <see cref="StreamingContext"/> to recreate the exception from.</param>
        /// <param name="info">The <see cref="SerializationInfo"/> to recreate the exception from.</param>
        private NotInitializedException(SerializationInfo info, StreamingContext context): base(info, context) {}
    }
}