using System;
using System.Collections;
using System.Collections.Generic;
using InfiniTec.Exchange.WebDav;

namespace InfiniTec.Exchange
{
    internal class PhoneNumberDictionary : IDictionary<PhoneNumberType, string>
    {
        private Item _Item;

        private string GetProperty(PhoneNumberType type)
        {
            switch (type)
            {
                case PhoneNumberType.AssistantPhone:
                    return WellknownProperties.Contact.AssistantPhone;
                case PhoneNumberType.BusinessFax:
                    return WellknownProperties.Contact.BusinessFax;
                case PhoneNumberType.BusinessPhone:
                    return WellknownProperties.Contact.BusinessPhone;
                case PhoneNumberType.BusinessPhone2:
                    return WellknownProperties.Contact.BusinessPhone2;
                case PhoneNumberType.Callback:
                    return WellknownProperties.Contact.Callback;
                case PhoneNumberType.CarPhone:
                    return WellknownProperties.Contact.CarPhone;
                case PhoneNumberType.CompanyMainPhone:
                    return WellknownProperties.Contact.CompanyMainPhone;
                case PhoneNumberType.HomeFax:
                    return WellknownProperties.Contact.HomeFax;
                case PhoneNumberType.HomePhone:
                    return WellknownProperties.Contact.HomePhone;
                case PhoneNumberType.HomePhone2:
                    return WellknownProperties.Contact.HomePhone2;
                case PhoneNumberType.OtherFax:
                    return WellknownProperties.Contact.OtherFax;
                case PhoneNumberType.Isdn:
                    return WellknownProperties.Contact.Isdn;
                case PhoneNumberType.MobilePhone:
                    return WellknownProperties.Contact.MobilePhone;
                case PhoneNumberType.OtherTelephone:
                    return WellknownProperties.Contact.OtherTelephone;
                case PhoneNumberType.Pager:
                    return WellknownProperties.Contact.Pager;
                case PhoneNumberType.PrimaryPhone:
                    return WellknownProperties.Contact.PrimaryPhone;
                case PhoneNumberType.RadioPhone:
                    return WellknownProperties.Contact.RadioPhone;
                case PhoneNumberType.Telex:
                    return WellknownProperties.Contact.Telex;
                case PhoneNumberType.TtyTddPhone:
                    return WellknownProperties.Contact.TtyTddPhone;
                default:
                    throw new NotSupportedException("The specified phonenumber type is not supported");
            }
        }

        public PhoneNumberDictionary(Item item)
        {
            _Item = item;
        }

        #region IDictionary<PhoneNumberType,string> Members

        public void Add(PhoneNumberType key, string value)
        {
            _Item.SetPropertyValue<string>(GetProperty(key), value);
        }

        public bool ContainsKey(PhoneNumberType key)
        {
            return _Item.Properties.Contains(GetProperty(key));
        }

        public ICollection<PhoneNumberType> Keys
        {
            get
            {
                List<PhoneNumberType> result;

                result = new List<PhoneNumberType>();

                foreach (PhoneNumberType type in Enum.GetValues(typeof (PhoneNumberType)))
                {
                    if (_Item.Properties.Contains(GetProperty(type))) result.Add(type);
                }
                return result;
            }
        }

        public bool Remove(PhoneNumberType key)
        {
            _Item.SetPropertyValue<string>(GetProperty(key), null);
            return true;
        }

        public bool TryGetValue(PhoneNumberType key, out string value)
        {
            value = _Item.GetPropertyValue<string>(GetProperty(key));

            return (value != null);
        }

        public ICollection<string> Values
        {
            get
            {
                List<string> result;

                result = new List<string>();

                foreach (PhoneNumberType type in Enum.GetValues(typeof (PhoneNumberType)))
                {
                    if (_Item.Properties.Contains(GetProperty(type)))
                        result.Add(this[type]);
                }
                return result;
            }
        }

        public bool Contains(PhoneNumberType key)
        {
            return _Item.Properties.Contains(GetProperty(key));
        }

        public string this[PhoneNumberType key]
        {
            get
            {
                if (!Contains(key)) throw new IndexOutOfRangeException("The specified number could not be found");

                return _Item.GetPropertyValue<string>(GetProperty(key));
            }
            set { _Item.SetPropertyValue<string>(GetProperty(key), value); }
        }

        #endregion

        #region ICollection<KeyValuePair<PhoneNumberType,string>> Members

        public void Add(KeyValuePair<PhoneNumberType, string> item)
        {
            Add(item.Key, item.Value);
        }

        public void Clear()
        {
            foreach (PhoneNumberType type in Keys)
            {
                this[type] = null;
            }
        }

        public bool Contains(KeyValuePair<PhoneNumberType, string> item)
        {
            return Contains(item.Key);
        }

        public void CopyTo(KeyValuePair<PhoneNumberType, string>[] array, int arrayIndex)
        {
            int index;
            index = arrayIndex;
            foreach (PhoneNumberType type in Keys)
            {
                array[index] = new KeyValuePair<PhoneNumberType, string>(type, this[type]);
                index++;
            }
        }

        public int Count
        {
            get { return Keys.Count; }
        }

        public bool IsReadOnly
        {
            get { return false; }
        }

        public bool Remove(KeyValuePair<PhoneNumberType, string> item)
        {
            return Remove(item.Key);
        }

        #endregion

        #region IEnumerable<KeyValuePair<PhoneNumberType,string>> Members

        public IEnumerator<KeyValuePair<PhoneNumberType, string>> GetEnumerator()
        {
            foreach (PhoneNumberType type in Keys)
            {
                yield return new KeyValuePair<PhoneNumberType, string>(type, this[type]);
            }
        }

        #endregion

        #region IEnumerable Members

        IEnumerator IEnumerable.GetEnumerator()
        {
            return ((IEnumerable<KeyValuePair<PhoneNumberType, string>>) this).GetEnumerator();
        }

        #endregion
    }
}