namespace InfiniTec.Exchange
{
    /// <summary>
    /// Specifies the scope of a search operation
    /// </summary>
    public enum SearchScope
    {
        /// <summary>
        /// The search operation is restricted to one level beneath the search root
        /// </summary>
        Shallow,
        /// <summary>
        /// The search operation is not restricted.
        /// </summary>
        /// <remarks>This search type is not supported on a public MAPI store, such as the public folders.
        /// It is, however, supported on private mailbox stores, as well as on other top level hierachies.</remarks>
        Deep,
        /// <summary>
        /// The search operation is restricted on folders.
        /// </summary>
        /// <remarks>A hierarchical traversal search can be used for a task such as determining the folder hierarchy 
        /// of a specified folder.</remarks>
        Hierarchical,
        /// <summary>
        /// The search operation is restricted to only level beneath the search root. Only deleted Items are searched.
        /// </summary>
        SoftDeleted
    }
}