using System;

namespace InfiniTec.Exchange.Security
{
    /// <summary>
    /// This enum defines the generic access masks defined for folder and
    /// items
    /// </summary>
    [Flags]
    public enum AccessMasks
    {
        /// <summary>
        /// No permissions
        /// </summary>
        None = 0x0,
        /// <summary>
        /// [Folder permission] The associated identity can see the folder
        /// </summary>
        FolderVisible = 0x1,
        /// <summary>
        /// [Folder permission] The associated identity is the folder contact
        /// </summary>
        FolderContact = 0x2,
        /// <summary>
        /// [Folder permission] The associated identity is the folder owner
        /// </summary>
        FolderOwner = 0x4,
        /// <summary>
        /// [Item permission]The associated identity can read the item
        /// </summary>
        Read = 0x8,
        /// <summary>
        /// [Item permission] The associated identity can edit his own items
        /// </summary>
        EditOwn = 0x10,
        /// <summary>
        /// [Item permission] The associated identity can edit any items
        /// </summary>
        EditAny = 0x20,
        /// <summary>
        /// [Item permission] The associated identity can delete his own items
        /// </summary>
        DeleteOwn = 0x40,
        /// <summary>
        /// [Item permission] The associated identity can delete any item
        /// </summary>
        DeleteAny = 0x80,
        /// <summary>
        /// [Folder permission] The associated identity can create sub folders
        /// </summary>
        CreateSubFolder = 0x100,
        /// <summary>
        /// [Folder permission] The associated identity can create items
        /// </summary>
        CreateItems = 0x200,
        /// <summary>
        /// Not actual a set of permissions. Only used for categorization.
        /// </summary>
        Special = 0x400
    }
}