using System;

namespace InfiniTec.Exchange.Security
{
    /// <summary>
    /// Defines low-level access masks for folder
    /// </summary>
    [Flags]
    public enum FolderAccessMasks
    {
        /// <summary>
        /// No permissions
        /// </summary>
        None = 0x0,
        /// <summary>
        /// List the contents of the folder
        /// </summary>
        ListContents = 0x1,
        /// <summary>
        /// Create new items in the folder
        /// </summary>
        CreateItem = 0x2,
        /// <summary>
        /// Create new folder in the folder
        /// </summary>
        CreateContainer = 0x4,
        /// <summary>
        /// Read properties of the folder
        /// </summary>
        ReadProperty = 0x8,
        /// <summary>
        /// Change propertis of the folder
        /// </summary>
        WriteProperty = 0x10,
        /// <summary>
        /// Change own properties of the folder
        /// </summary>
        WriteOwnProperties = 0x20,
        /// <summary>
        /// Delete own items in the folder
        /// </summary>
        DeleteOwnItem = 0x40,
        /// <summary>
        /// Same as ReadProperty
        /// </summary>
        ReadAttributes = 0x80,
        /// <summary>
        /// Same as WriteProperty
        /// </summary>
        WriteAttributes = 0x100,
        /// <summary>
        /// View items in this folder
        /// </summary>
        ViewItems = 0x800,
        /// <summary>
        /// Sets the owner flag of the folder
        /// </summary>
        Owner = 0x4000,
        /// <summary>
        /// Sets the contact of the folder
        /// </summary>
        Contact = 0x8000,
        /// <summary>
        /// Delete items
        /// </summary>
        Delete = 0x10000,
        /// <summary>
        /// Read the security descriptor
        /// </summary>
        ReadControl = 0x20000,
        /// <summary>
        /// Change the security descriptor
        /// </summary>
        WriteSecurityDescriptor = 0x40000,
        /// <summary>
        /// Change the owner of the folder
        /// </summary>
        WriteOwner = 0x80000,
        /// <summary>
        /// Unknown
        /// </summary>
        Synchronize = 0x100000,
        /// <summary>
        /// Create new items
        /// </summary>
        CreateItems = 0x2,
        /// <summary>
        /// Read items
        /// </summary>
        ReadItems = 0x800,
        /// <summary>
        /// Create new folders in this folder
        /// </summary>
        CreateSubfolder = 0x4,
        /// <summary>
        /// Folder-owner permission set
        /// </summary>
        FolderOwner = 0xd4910,
        /// <summary>
        /// Folder contact permission set
        /// </summary>
        FolderContact = 0x8000,
        /// <summary>
        /// Folder visible permission set
        /// </summary>
        FolderVisible = 0x1200a9,
        /// <summary>
        /// A combination of all permissions
        /// </summary>
        All =
            ListContents | CreateItem | CreateContainer | ReadProperty | WriteProperty | WriteOwnProperties |
            DeleteOwnItem | ReadAttributes | WriteAttributes | ViewItems | Owner | Contact | Delete | ReadControl |
            WriteSecurityDescriptor | WriteOwner | Synchronize
    }
}