using System;

namespace InfiniTec.Exchange.Security
{
    /// <summary>
    /// Provides low level access permissions for Exchange items
    /// </summary>
    [Flags]
    public enum ItemAccessMasks
    {
        /// <summary>
        /// No permission
        /// </summary>
        None = 0x0,
        /// <summary>
        /// Read the body of the item
        /// </summary>
        ReadBody = 0x1,
        /// <summary>
        /// Change the body of the item
        /// </summary>
        WriteBody = 0x2,
        /// <summary>
        /// Append information to the item
        /// </summary>
        AppendMessage = 0x4,
        /// <summary>
        /// Read a property of the item
        /// </summary>
        ReadProperty = 0x8,
        /// <summary>
        /// Modify a property of the item
        /// </summary>
        WriteProperty = 0x10,
        /// <summary>
        /// Unknown
        /// </summary>
        Execute = 0x20,
        /// <summary>
        /// Same as read property
        /// </summary>
        ReadAttributes = 0x80,
        /// <summary>
        /// Same as write property
        /// </summary>
        WriteAttributes = 0x100,
        /// <summary>
        /// Modify own properties
        /// </summary>
        WriteOwnProperty = 0x200,
        /// <summary>
        /// Delete own items
        /// </summary>
        DeleteOwnItem = 0x400,
        /// <summary>
        /// Read the contents of the item
        /// </summary>
        ViewItem = 0x800,
        /// <summary>
        /// Delete the item
        /// </summary>
        Delete = 0x10000,
        /// <summary>
        /// Unkwown
        /// </summary>
        ReadControl = 0x20000,
        /// <summary>
        /// Modify the security descriptor
        /// </summary>
        WriteSecurityDescriptor = 0x40000,
        /// <summary>
        /// Modify the owner of this item
        /// </summary>
        WriteOwner = 0x80000,
        /// <summary>
        /// Unknown
        /// </summary>
        Synchronize = 0x100000,
        /// <summary>
        /// Read the content of the item
        /// </summary>
        ReadItem = 0x1208a9,
        /// <summary>
        /// Edit own items
        /// </summary>
        EditOwn = 0x200,
        /// <summary>
        /// Edit any items
        /// </summary>
        EditAny = 0x1e0116,
        /// <summary>
        /// Delete own items
        /// </summary>
        DeleteOwn = 0x400,
        /// <summary>
        /// Delete any item
        /// </summary>
        DeleteAny = 0x10000,
        /// <summary>
        /// Combined value of all properties
        /// </summary>
        All =
            ReadBody | WriteBody | AppendMessage | ReadProperty | WriteProperty | Execute | ReadAttributes |
            WriteAttributes | WriteOwnProperty | DeleteOwnItem | ViewItem | Delete | ReadControl |
            WriteSecurityDescriptor | WriteOwner | Synchronize
    }
}