using System;
using System.ComponentModel;

namespace InfiniTec.Exchange.WebDav
{
    /// <summary>
    /// This class contains information about a completed asynchronous copy operation.
    /// </summary>
    public class CopyCompletedEventArgs : AsyncCompletedEventArgs
    {
        private ItemBase _NewItem;

        /// <summary>
        /// The newly created item.
        /// </summary>
        public ItemBase NewItem
        {
            get { return _NewItem; }
        }

        /// <summary>
        /// Creates a new instance indicating the failure of the copy operation.
        /// </summary>
        /// <param name="exception">The exception which occured during the copy operation.</param>
        public CopyCompletedEventArgs(Exception exception) : base(exception, false, null)
        {
        }

        /// <summary>
        /// Creates a new instance indicating the success of the copy operation.
        /// </summary>
        /// <param name="newItem">The newly created item.</param>
        public CopyCompletedEventArgs(ItemBase newItem) : this(false)
        {
            _NewItem = newItem;
        }

        /// <summary>
        /// Creates a new instance indicating the success or abortion of the copy operation.
        /// </summary>
        /// <param name="cancelled">True, if the operation was cancelled. False, otherwise</param>
        public CopyCompletedEventArgs(bool cancelled)
            : base(null, cancelled, null)
        {
        }
    }
}