namespace InfiniTec.Exchange.WebDav
{
    /// <summary>
    /// This class represents a public or private folder on an Exchange store.
    /// </summary>
    public class Folder : FolderBase
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="Folder"/> class.
        /// </summary>
        /// <param name="path">The path of the folder on the server.</param>
        /// <param name="connection">The <see cref="Connection"/> to use.</param>
        /// <param name="propertiesToLoad">The properties to retrieve. If omitted, all properties are retrieved.</param>
        public Folder(string path, Connection connection, params string[] propertiesToLoad) :
            base(path, connection, propertiesToLoad)
        {
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="Folder"/> class.
        /// </summary>
        /// <param name="path">The path.</param>
        /// <param name="connection">The connection.</param>
        /// <param name="isNew">if set to <c>true</c> [is new].</param>
        /// <param name="propertiesToLoad">The properties to load.</param>
        protected Folder(string path, Connection connection, bool isNew, params string[] propertiesToLoad) :
            base(path, connection, isNew, propertiesToLoad)
        {
        }

        /// <summary>
        /// Returns a <see cref="Searcher"/> which can be used
        /// to search the current folder.
        /// </summary>
        /// <param name="propertiesToLoad">Optional. Specifies the
        /// properties to search for.</param>
        /// <returns>A <see cref="Searcher"/> instance.</returns>
        public Searcher Search(params string[] propertiesToLoad)
        {
            return new Searcher(Url, Connection, propertiesToLoad);
        }

        /// <summary>
        /// Creates a new folder with the specified path.
        /// </summary>
        /// <param name="path">The path of the new folder.</param>
        /// <param name="connection">The <see cref="Connection"/> to use.</param>
        /// <returns>A <see cref="Folder"/> object</returns>
        public static Folder Create(string path, Connection connection)
        {
            return new Folder(path, connection, true);
        }
    }
}