namespace InfiniTec.Exchange.WebDav
{
    /// <summary>
    /// This class represents a public or private folder on an Exchange store.
    /// </summary>
    public class Folder<ItemType> : FolderBase
        where ItemType : Item, new()
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="Folder&lt;ItemType&gt;"/> class.
        /// </summary>
        /// <param name="path">The path of the folder on the server.</param>
        /// <param name="connection">The <see cref="Connection"/> to use.</param>
        /// <param name="propertiesToLoad">The properties to retrieve. If omitted, all properties are retrieved.</param>
        public Folder(string path, Connection connection, params string[] propertiesToLoad)
            : base(path, connection, propertiesToLoad)
        {
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="Folder&lt;ItemType&gt;"/> class.
        /// </summary>
        /// <param name="path">The path.</param>
        /// <param name="connection">The connection.</param>
        /// <param name="isNew">if set to <c>true</c> [is new].</param>
        /// <param name="propertiesToLoad">The properties to load.</param>
        protected Folder(string path, Connection connection, bool isNew, params string[] propertiesToLoad)
            : base(path, connection, isNew, propertiesToLoad)
        {
        }


        /// <summary>
        /// Returns all child items of the current folder.
        /// </summary>
        /// <returns></returns>
        public Searcher<ItemType> FindChildItems()
        {
            return FindChildItems("\"DAV:ishidden\" = false and \"DAV:isfolder\" = false");
        }

        /// <summary>
        /// Finds all the child items matching the specified constraint.
        /// </summary>
        /// <param name="constraints">The constraints to apply to the search</param>
        /// <returns></returns>
        public Searcher<ItemType> FindChildItems(string constraints)
        {
            Searcher<ItemType> searcher;

            searcher = new Searcher<ItemType>(Url, Connection);
            searcher.Constraints = constraints;

            return searcher;
        }
    }
}