using System;
using System.Collections.Generic;
using System.IO;
using System.Net;

namespace InfiniTec.Exchange.WebDav.Request
{
    /// <summary>
    /// This class contains information about an asynchronous WebDav request.
    /// </summary>
    public class RequestSettings
    {
        private WebHeaderCollection _Headers;
        private IList<Range> _Ranges;
        private Uri _Url;
        private string _Method;
        private Stream _Request;
        private Stream _OutputStream;

        /// <summary>
        /// Gets or sets the stream which is used to store the response of the request.
        /// If set to Null (Nothing in Visual Basic), the output is treated as an XML document
        /// and parsed into the <see cref="M:Response.Content"/> stream.
        /// </summary>
        public Stream OutputStream
        {
            get { return _OutputStream; }
            set { _OutputStream = value; }
        }

        /// <summary>
        /// Provides access the request headers that are send along 
        /// with the request.
        /// </summary>
        public WebHeaderCollection Headers
        {
            get { return _Headers; }
        }

        /// <summary>
        /// Provides access to a collection of ranges that are send
        /// along with the request.
        /// </summary>
        public IList<Range> Ranges
        {
            get { return _Ranges; }
        }

        /// <summary>
        /// Gets or sets the <see cref="Uri"/> of the request.
        /// </summary>
        public Uri Url
        {
            get { return _Url; }
            set { _Url = value; }
        }

        /// <summary>
        /// Gets or sets the HTTP/WebDAV verb used for the request.
        /// </summary>
        public string Method
        {
            get { return _Method; }
            set { _Method = value; }
        }

        /// <summary>
        /// Gets or sets the data that is sent to the server during
        /// the request.
        /// </summary>
        public Stream Request
        {
            get { return _Request; }
            set { _Request = value; }
        }

        /// <summary>
        /// Creates new instance of this class.
        /// </summary>
        /// <param name="url">The <see cref="Uri"/> of the request.</param>
        /// <param name="method">The verb to use.</param>
        public RequestSettings(Uri url, string method)
        {
            _Ranges = new List<Range>();
            _Headers = new WebHeaderCollection();

            _Url = url;
            _Method = method;
        }
    }
}