using System;
using System.Runtime.Serialization;
using InfiniTec.Exchange.WebDav.Request;

namespace InfiniTec.Exchange.WebDav
{
    /// <summary>
    /// This exception is used to indicate the failure of a WebDav request operation.
    /// </summary>
    [Serializable]
    public class RequestFailedException : Exception
    {
        private RequestStatus _Status;

        /// <summary>
        /// The <see cref="RequestStatus"/> of the operation.
        /// </summary>
        public RequestStatus Status
        {
            get { return _Status; }
            set { _Status = value; }
        }

        /// <summary>
        /// Initiates a new instance of this class.
        /// </summary>
        /// <param name="status">The status of the request. </param>
        public RequestFailedException(RequestStatus status)
        {
            _Status = status;
        }

        /// <summary>
        /// Initiates a new instance of this class.
        /// </summary>
        /// <param name="status">The status of the request. </param>
        /// <param name="message">The message of the exception</param>
        public RequestFailedException(RequestStatus status, string message) : base(message)
        {
            _Status = status;
        }

        /// <summary>
        /// Initiates a new instance of this class.
        /// </summary>
        /// <param name="status">The status of the request. </param>
        /// <param name="message">The message of the request</param>
        /// <param name="inner">An inner exception</param>
        public RequestFailedException(RequestStatus status, string message, Exception inner)
            : base(message, inner)
        {
            _Status = Status;
        }

        /// <summary>
        /// Initiates a new instance of this class.
        /// </summary>
        /// <param name="info">A <see cref="SerializationInfo"/> instance.</param>
        /// <param name="context">A <see cref="StreamingContext"/> instance.</param>
        protected RequestFailedException(
            SerializationInfo info,
            StreamingContext context)
            : base(info, context)
        {
        }
    }
}