using System.Collections.Generic;
using System.ComponentModel;

namespace InfiniTec.Exchange.WebDav
{
    /// <summary>
    /// This class contains information about an ongoing search operation.
    /// </summary>
    public class SearchProgressChangedEventArgs : CancelEventArgs
    {
        private IList<SimpleItem> _Items;
        private Range _Range;

        /// <summary>
        /// Returns the range of the current operation.
        /// </summary>
        public Range Range
        {
            get { return _Range; }
        }

        /// <summary>m
        /// Returns a collections of <see cref="Item"/>s.
        /// </summary>
        public IList<SimpleItem> Items
        {
            get { return _Items; }
        }

        /// <summary>
        /// Creates a new instance of this class.
        /// </summary>
        /// <param name="items">The items which were found during the last request </param>
        /// <param name="range">The range of the found items</param>
        /// 
        public SearchProgressChangedEventArgs(Range range, IEnumerable<SimpleItem> items)
        {
            _Items = new List<SimpleItem>(items).AsReadOnly();
            _Range = range;
        }
    }
}