namespace InfiniTec.Exchange
{
    /// <summary>
    /// This class defines constants for some properties.
    /// </summary>
    public static class WellknownProperties
    {
        /// <summary>
        /// Security-related properties
        /// </summary>
        public static class Security
        {
            /// <summary>
            /// The binary security descriptor of the item in 
            /// </summary>
            public const string NTSecurityDescriptor = Namespaces.Exchange + "ntsecuritydescriptor";

            /// <summary>
            /// The old property for the binary security descriptor an item
            /// </summary>
            public const string PR_ACL_Table = Namespaces.MapiPropTag + "x3fe0000d";

            /// <summary>
            /// The binary security descriptor of the item in 
            /// </summary>
            public const string PR_NT_Security_Descriptor = Namespaces.MapiPropTag + "x0e270102";
        }

        /// <summary>
        /// Standard DAV properties
        /// </summary>
        public static class Dav
        {
            /// <summary>
            /// The property indicating whether an item is a folder or not
            /// </summary>
            public const string IsFolder = Namespaces.Dav + "isfolder";
        }

        /// <summary>
        /// This class contains names of properties for attachments.
        /// </summary>
        public static class Attachment
        {
            /// <summary>
            /// This property contains the size of the attachment.
            /// </summary>
            public const string Size = Namespaces.MapiPropTag + "x0E210003";

            /// <summary>
            /// This property containt the name of the attachment
            /// </summary>
            public const string Filename = Namespaces.MapiPropTag + "x3707001f";

            /// <summary>
            /// This property containt the name of the attachment
            /// </summary>
            public const string Filename2 = Namespaces.MapiPropTag + "x3704001f";

            /// <summary>
            /// This property containt the name of the attachment
            /// </summary>
            public const string LongFilename = Namespaces.HttpMail + "attachmentfilename";

            /// <summary>
            /// This property contains the content-disposition (inline, attachment, etc) of an attachment.
            /// </summary>
            public const string ContentDisposition = Namespaces.MapiPropTag + "x3716001e";

            /// <summary>
            /// This property contains the MIME type of the attachment.
            /// </summary>
            public const string MimeType = Namespaces.MapiPropTag + "x370e001f";
        }

        /// <summary>
        /// This class defines various properties used on all items.
        /// </summary>
        public static class Item
        {
            /// <summary>
            /// Specifies the content class of the item
            /// </summary>
            public const string ContentClass = Namespaces.Dav + "contentclass";

            /// <summary>
            /// Specifies the item class of the element
            /// </summary>
            public const string ItemClass = Namespaces.Exchange + "outlookmessageclass";

            /// <summary>
            /// Specifies the subject of the item
            /// </summary>
            public const string Subject = "urn:schemas:httpmail:subject";

            /// <summary>
            /// Specifies the sensitity of the item
            /// </summary>
            public const string Sensitivity = Namespaces.Exchange + "sensitivity";

            /// <summary>
            /// Specifies the the received date of the item.
            /// </summary>
            public const string Received = "urn:schemas:httpmail:datereceived";

            /// <summary>
            /// Specifies the message size of the item
            /// </summary>
            public const string MessageSize = Namespaces.MapiPropTag + "xe080003";

            /// <summary>
            /// Specifies the categories of the item
            /// </summary>
            public const string Categories = "http://schemas.microsoft.com/exchange/keywords-utf8";

            /// <summary>
            /// Specifies the importance of the item
            /// </summary>
            public const string Importance = "urn:schemas:httpmail:importance";

            /// <summary>
            /// Specifies the message id of the original message
            /// </summary>
            public const string InReplyTo = Namespaces.MapiPropTag + "x1042001f";

            /// <summary>
            /// Specifies the IsSubmitted property of the message.
            /// </summary>
            public const string IsSubmitted = "urn:schemas:httpmail:submitted";

            /// <summary>
            /// Specifies the text body of the item.
            /// </summary>
            public const string TextBody = Namespaces.MapiPropTag + "x1000001f";

            /// <summary>
            /// Specifies the html body of the item.
            /// </summary>
            public const string HtmlBody = Namespaces.MapiPropTag + "x1013001f";

            /// <summary>
            /// Specifies the message flags of the item
            /// </summary>
            public const string MessageFlags = Namespaces.MapiPropTag + "xe070003";

            /// <summary>
            /// Specifies the sent date of te item
            /// </summary>
            public const string SentDate = Namespaces.MapiPropTag + "x390040";

            /// <summary>
            /// Specifies the creation date of the item.
            /// </summary>
            public const string CreationDate = Namespaces.MapiPropTag + "x30070040";

            /// <summary>
            /// Specifies the reply to names of the item.
            /// </summary>
            public const string ReplyToNames = Namespaces.MapiPropTag + "x50001f";

            /// <summary>
            /// Specifies the date/tim of the reminder
            /// </summary>
            public const string ReminderDueBy = Namespaces.PropertySets.Common + "0x8502";

            /// <summary> 
            /// Specifies the whether the reminder has been set.
            /// </summary>
            public const string ReminderIsSet = Namespaces.PropertySets.Common + "0x8503";

            /// <summary>
            /// Specifies the remoinder minutes before start of the item.
            /// </summary>
            public const string ReminderMinutesBeforeState = Namespaces.PropertySets.Common + "0x8501";

            /// <summary>
            /// Specifies whether the item has any attachments.
            /// </summary>
            public const string HasAttachments = Namespaces.MapiPropTag + "xe1b000b";

            /// <summary>
            /// Specifies the lastverb executed.
            /// </summary>
            public const string LastVerbExecuted = Namespaces.MapiPropTag + "x10810003";

            /// <summary>
            /// Specifies the execution time of the last verb.
            /// </summary>
            public const string LastVerbExecutedOn = Namespaces.MapiPropTag + "x10820040";

            /// <summary>
            /// Specifies the icon index corresponding to the last verb executed.
            /// </summary>
            public const string IconIndex = Namespaces.MapiPropTag + "x10800003";

            /// <summary>
            /// Specifies the message headers of the item
            /// </summary>
            public const string MessageHeaders = Namespaces.MapiPropTag + "x7d001f";
        }

        /// <summary>
        /// This class defines various properties available on message items.
        /// </summary>
        public static class Message
        {
            /// <summary>
            /// Specifies the Sender of the message.
            /// </summary>
            public const string Sender = "urn:schemas:httpmail:sender";

            /// <summary>
            /// Specifies the from address of the message.
            /// </summary>
            public const string From = "urn:schemas:httpmail:from";

            /// <summary>
            /// Specifies the TO addresses of the message.
            /// </summary>
            public const string To = "urn:schemas:httpmail:to";

            /// <summary>
            /// Specifies the CC addresses of the item
            /// </summary>
            public const string Cc = "urn:schemas:httpmail:cc";

            /// <summary>
            /// Specifies the Bcc addresses of the message
            /// </summary>
            public const string Bcc = "urn:schemas:httpmail:bcc";

            /// <summary>
            /// Specifies the reply to addrsses of the item
            /// </summary>
            public const string ReplyTo = "urn:schemas:httpmail:replyto";

            /// <summary>
            /// Specifies the conversation index of the item
            /// </summary>
            public const string ConversationIndex = Namespaces.MapiPropTag + "x710102";

            /// <summary>
            /// Specifies the property of the Responserequested flag of the message.
            /// </summary>
            public const string ResponseRequested = Namespaces.MapiPropTag + "x63000b";

            /// <summary>
            /// Specifies the property of the ReadReceiptRequested flag of the message
            /// </summary>
            public const string ReadReceiptRequested = Namespaces.MapiPropTag + "x29000b";

            /// <summary>
            /// Specifies the property of the DeliveryReceiptRequested flag of the message.
            /// </summary>
            public const string DeliveryReceiptRequested = Namespaces.MapiPropTag + "x23000b";

            /// <summary>
            /// Specifies the conversationtopic of the message.
            /// </summary>
            public const string ConversationTopic = Namespaces.MapiPropTag + "x70001f";

            /// <summary>
            /// Specifies the message id of the message
            /// </summary>
            public const string InternetMessageId = Namespaces.MapiPropTag + "x1035001f";

            /// <summary>
            /// Specifies the references of the message.
            /// </summary>
            public const string References = Namespaces.MapiPropTag + "x1039001f";

            /// <summary>
            /// Specifies the spam confidence level of the message
            /// </summary>
            public const string SpamConfidenceLevel = Namespaces.MapiPropTag + "x40760003";

            /// <summary>
            /// Specified the property containing the internet message header
            /// </summary>
            public const string InternetMessageHeader = Namespaces.MapiPropTag + "x7d001f";
        }

        /// <summary>
        /// This class defines names of properties used on task items.
        /// </summary>
        public static class Task
        {
            /// <summary>
            /// Specifies the propertyname for the actual work of the task
            /// </summary>
            public const string ActualWork = Namespaces.PropertySets.Tasks + "0x8110";

            /// <summary>
            /// Specifies the propertyname for the assigned time.
            /// </summary>
            public const string AssignedTime = Namespaces.PropertySets.Tasks + "0x8115";

            /// <summary>
            /// Specifies the propertyname for the billing information
            /// </summary>
            public const string BillingInformation = Namespaces.PropertySets.Common + "0x8535";

            /// <summary>
            /// Specifies the propertyname for the change count
            /// </summary>
            public const string ChangeCount = Namespaces.PropertySets.Tasks + "0x8112";

            /// <summary>
            /// Specifies the propertyname for the companies
            /// </summary>
            public const string Companies = Namespaces.PropertySets.Common + "0x8539";

            /// <summary>
            /// Specifies the propertyname for the completion date
            /// </summary>
            public const string CompleteDate = Namespaces.PropertySets.Tasks + "0x810f";

            /// <summary>
            /// Specifies the propertyname for the contacts
            /// </summary>
            public const string Contacts = Namespaces.PropertySets.Common + "0x853a";

            /// <summary>
            /// Specifies the propertyname for the delegation status
            /// </summary>
            public const string DelegationState = Namespaces.PropertySets.Tasks + "0x812a";

            /// <summary>
            /// Specifies the propertyname for the delegator
            /// </summary>
            public const string Delegator = Namespaces.PropertySets.Tasks + "0x8121";

            /// <summary>
            /// Specifies the propertyname for the due date
            /// </summary>
            public const string DueDate = Namespaces.PropertySets.Tasks + "0x8105";

            /// <summary>
            /// Specifies the propertyname for the due date
            /// </summary>
            public const string UtcDueDate = Namespaces.PropertySets.Common + "0x8517";

            /// <summary>
            /// Specifies the propertyname for the flag indicating whether the assignment is editable
            /// </summary>
            public const string IsAssignmentEditable = Namespaces.PropertySets.Common + "0x8518";

            /// <summary>
            /// Specifies the propertyname for the flag indicating whether the task is complete
            /// </summary>
            public const string IsComplete = Namespaces.PropertySets.Tasks + "0x811c";

            /// <summary>
            /// Specifies the propertyname for the flag indiciating whether the task is recurring 
            /// </summary>
            public const string IsRecurring = Namespaces.PropertySets.Tasks + "0x8126";

            /// <summary>
            /// Specifies the propertyname for the flag indicating whether the task is a team task
            /// </summary>
            public const string IsTeamTask = Namespaces.PropertySets.Tasks + "0x8103";

            /// <summary>
            /// Specifies the propertyname for the mileage
            /// </summary>
            public const string Mileage = Namespaces.PropertySets.Common + "0x8534";

            /// <summary>
            /// Specifies the propertyname for the owner
            /// </summary>
            public const string Owner = Namespaces.PropertySets.Tasks + "0x811f";

            /// <summary>
            /// Specifies the propertyname for the percent complete property.
            /// </summary>
            public const string PercentComplete = Namespaces.PropertySets.Tasks + "0x8102";

            /// <summary>
            /// Specifies the propertyname for the start date
            /// </summary>
            public const string StartDate = Namespaces.PropertySets.Common + "0x8516";

            /// <summary>
            /// Specifies the propertyname for the end date
            /// </summary>
            public const string EndDate = Namespaces.PropertySets.Common + "0x8517";

            /// <summary>
            /// Specifies the propertyname for the task status
            /// </summary>
            public const string TaskStatus = Namespaces.PropertySets.Tasks + "0x8101";

            /// <summary>
            /// Specifies the propertyname for the status description
            /// </summary>
            public const string StatusDescription = Namespaces.PropertySets.Tasks + "0x8137";

            /// <summary>
            /// Specifies the propertyname for the total work
            /// </summary>
            public const string TotalWork = Namespaces.PropertySets.Tasks + "0x8111";

            /// <summary>
            /// Specifies the propertyname for the task recurrence
            /// </summary>
            public const string TaskRecurrence = Namespaces.PropertySets.Tasks + "0x8116";

            /// <summary>
            /// Specifies the propertyname for the flag complete time
            /// </summary>
            public const string FlagCompleteTime = Namespaces.MapiPropTag + "x10910040";
        }

        /// <summary>
        /// This class defines the names of various properties defined on contacts
        /// </summary>
        public static class Contact
        {
            /// <summary>
            /// Specifies the propertyname for the file as property
            /// </summary>
            public const string FileAs = "urn:schemas:contacts:fileas";

            /// <summary>
            /// Specifies the propertyname for the file ass mapping
            /// </summary>
            public const string FileAsMapping = "urn:schemas:contacts:fileasid";

            /// <summary>
            /// Specifies the propertyname for the displayname
            /// </summary>
            public const string DisplayName = Namespaces.MapiPropTag + "x3001001f";

            /// <summary>
            /// Specifies the propertyname for the given name
            /// </summary>
            public const string GivenName = Namespaces.MapiPropTag + "x3a06001f";

            /// <summary>
            /// Specifies the propertyname for the initials
            /// </summary>
            public const string Initials = Namespaces.MapiPropTag + "x3a0a001f";

            /// <summary>
            /// Specifies the propertyname for the middle name
            /// </summary>
            public const string MiddleName = Namespaces.MapiPropTag + "x3a44001f";

            /// <summary>
            /// Specifies the propertyname for the nickname
            /// </summary>
            public const string NickName = Namespaces.MapiPropTag + "x3a4f001f";

            /// <summary>
            /// Specifies the propertyname for the job title
            /// </summary>
            public const string JobTitle = Namespaces.MapiPropTag + "x3a17001f";

            /// <summary>
            /// Specifies the propertyname for the prefix
            /// </summary>
            public const string Prefix = Namespaces.MapiPropTag + "x3a45001f";

            /// <summary>
            /// Specifies the propertyname for the surname
            /// </summary>
            public const string Surname = Namespaces.MapiPropTag + "x3a11001f";

            /// <summary>
            /// Specifies the propertyname for the yomi first name
            /// </summary>
            public const string YomiFirstName = Namespaces.PropertySets.Address + "0x802c";

            /// <summary>
            /// Specifies the propertyname for the yomi last name
            /// </summary>
            public const string YomiLastName = Namespaces.PropertySets.Address + "0x802d";

            /// <summary>
            /// Specifies the propertyname for the company name
            /// </summary>
            public const string CompanyName = Namespaces.MapiPropTag + "x3a16001f";

            /// <summary>
            /// Specifies the propertyname for the display name of the first email
            /// </summary>
            public const string Email1DisplayName = Namespaces.PropertySets.Address + "0x8080";

            /// <summary>
            /// Specifies the propertyname for the address type of the first email
            /// </summary>
            public const string Email1AddressType = Namespaces.PropertySets.Address + "0x8082";

            /// <summary>
            /// Specifies the propertyname for the address of the first email 
            /// </summary>
            public const string Email1EmailAddress = Namespaces.PropertySets.Address + "0x8083";

            /// <summary>
            /// Specifies the propertyname for the display name of the second email
            /// </summary>
            public const string Email2DisplayName = Namespaces.PropertySets.Address + "0x8090";

            /// <summary>
            /// Specifies the propertyname for the address type of the second email
            /// </summary>
            public const string Email2AddressType = Namespaces.PropertySets.Address + "0x8092";

            /// <summary>
            /// Specifies the propertyname for the address of the second email 
            /// </summary>
            public const string Email2EmailAddress = Namespaces.PropertySets.Address + "0x8093";

            /// <summary>
            /// Specifies the propertyname for the display name of the third email
            /// </summary>
            public const string Email3DisplayName = Namespaces.PropertySets.Address + "0x80a0";

            /// <summary>
            /// Specifies the propertyname for the address type of the third email
            /// </summary>
            public const string Email3AddressType = Namespaces.PropertySets.Address + "0x80a2";

            /// <summary>
            /// Specifies the propertyname for the address of the third email 
            /// </summary>
            public const string Email3EmailAddress = Namespaces.PropertySets.Address + "0x80a3";

            /// <summary>
            /// Specifies the propertyname for the home address city
            /// </summary>
            public const string HomeAddressCity = Namespaces.MapiPropTag + "x3a59001f";

            /// <summary>
            /// Specifies the propertyname for the home address country
            /// </summary>
            public const string HomeAddressCountry = Namespaces.MapiPropTag + "x3a5a001f";

            /// <summary>
            /// Specifies the propertyname for the home address postal code
            /// </summary>
            public const string HomePostalCode = Namespaces.MapiPropTag + "x3a5b001f";

            /// <summary>
            /// Specifies the propertyname for the home addres PO box
            /// </summary>
            public const string HomePostOfficeBox = Namespaces.MapiPropTag + "x3a5e001f";

            /// <summary>
            /// Specifies the propertyname for the home address state or province
            /// </summary>
            public const string HomeStateOrProvince = Namespaces.MapiPropTag + "x3a5c001f";

            /// <summary>
            /// Specifies the propertyname for the home street.
            /// </summary>
            public const string HomeStreet = Namespaces.MapiPropTag + "x3a5d001f";

            /// <summary>
            /// Specifies the propertyname for the home fax number
            /// </summary>
            public const string HomeFaxNumber = Namespaces.MapiPropTag + "x3a25001f";

            /// <summary>
            /// Specifies the propertyname for the other city
            /// </summary>
            public const string OtherCity = Namespaces.MapiPropTag + "x3a5f001f";

            /// <summary>
            /// Specifies the propertyname for the other country
            /// </summary>
            public const string OtherCountry = Namespaces.MapiPropTag + "x3a60001f";

            /// <summary>
            /// Specifies the propertyname for the other address postal code
            /// </summary>
            public const string OtherPostalCode = Namespaces.MapiPropTag + "x3a61001f";

            /// <summary>
            /// Specifies the propertyname for the other address PO box
            /// </summary>
            public const string OtherPostOfficeBox = Namespaces.MapiPropTag + "x3a64001f";

            /// <summary>
            /// Specifies the propertyname for the other address state or province
            /// </summary>
            public const string OtherStateOrProvince = Namespaces.MapiPropTag + "x3a62001f";

            /// <summary>
            /// Specifies the propertyname for the other address street 
            /// </summary>
            public const string OtherStreet = Namespaces.MapiPropTag + "x3a63001f";

            /// <summary>
            /// Specifies the propertyname for the business city
            /// </summary>
            public const string BusinessCity = Namespaces.PropertySets.Address + "0x8046";

            /// <summary>
            /// Specifies the propertyname for the business country
            /// </summary>
            public const string BusinessCountry = Namespaces.PropertySets.Address + "0x8049";

            /// <summary>
            /// Specifies the propertyname for the business postal code
            /// </summary>
            public const string BusinessPostalCode = Namespaces.PropertySets.Address + "0x8048";

            /// <summary>
            /// Specifies the propertyname for the business PO box
            /// </summary>
            public const string BusinessPostOfficeBox = Namespaces.PropertySets.Address + "0x804A";

            /// <summary>
            /// Specifies the propertyname for the business state or province
            /// </summary>
            public const string BusinessStateOrProvince = Namespaces.PropertySets.Address + "0x8047";

            /// <summary>
            /// Specifies the propertyname for the business street
            /// </summary>
            public const string BusinessStreet = Namespaces.PropertySets.Address + "0x8045";

            /// <summary>
            /// Specifies the propertyname for the assistant phone
            /// </summary>
            public const string AssistantPhone = Namespaces.MapiPropTag + "x3a2e001f";

            /// <summary>
            /// Specifies the propertyname for the other fax
            /// </summary>
            public const string OtherFax = Namespaces.MapiPropTag + "x3a23001f";

            /// <summary>
            /// Specifies the propertyname for the business fax
            /// </summary>
            public const string BusinessFax = Namespaces.MapiPropTag + "x3a24001f";

            /// <summary>
            /// Specifies the propertyname for the business phone
            /// </summary>
            public const string BusinessPhone = Namespaces.MapiPropTag + "x3a08001f";

            /// <summary>
            /// Specifies the propertyname for the second business phone
            /// </summary>
            public const string BusinessPhone2 = Namespaces.MapiPropTag + "x3a1b001f";

            /// <summary>
            /// Specifies the propertyname for the callback phone number
            /// </summary>
            public const string Callback = Namespaces.MapiPropTag + "x3a02001f";

            /// <summary>
            /// Specifies the propertyname for the car phone.
            /// </summary>
            public const string CarPhone = Namespaces.MapiPropTag + "x3a1e001f";

            /// <summary>
            /// Specifies the propertyname for the company main phone
            /// </summary>
            public const string CompanyMainPhone = Namespaces.MapiPropTag + "x3a57001f";

            /// <summary>
            /// Specifies the propertyname for the home fax
            /// </summary>
            public const string HomeFax = Namespaces.MapiPropTag + "x3a25001f";

            /// <summary>
            /// Specifies the propertyname for the home phone
            /// </summary>
            public const string HomePhone = Namespaces.MapiPropTag + "x3a09001f";

            /// <summary>
            /// Specifies the propertyname for the secondary home phone
            /// </summary>
            public const string HomePhone2 = Namespaces.MapiPropTag + "x3a2f001f";

            /// <summary>
            /// Specifies the propertyname for the isdn phone
            /// </summary>
            public const string Isdn = Namespaces.MapiPropTag + "x3a2d001f";

            /// <summary>
            /// Specifies the propertyname for the mobile phone
            /// </summary>
            public const string MobilePhone = Namespaces.MapiPropTag + "x3a1c001f";

            /// <summary>
            /// Specifies the propertyname for the other telephone
            /// </summary>
            public const string OtherTelephone = Namespaces.MapiPropTag + "x3a1f001f";

            /// <summary>
            /// Specifies the propertyname for the pager
            /// </summary>
            public const string Pager = Namespaces.MapiPropTag + "x3a21001f";

            /// <summary>
            /// Specifies the propertyname for the primary phone
            /// </summary>
            public const string PrimaryPhone = Namespaces.MapiPropTag + "x3a1a001f";

            /// <summary>
            /// Specifies the propertyname for the radio phone
            /// </summary>
            public const string RadioPhone = Namespaces.MapiPropTag + "x3a1d001f";

            /// <summary>
            /// Specifies the propertyname for the telex
            /// </summary>
            public const string Telex = Namespaces.MapiPropTag + "x3a2c001f";

            /// <summary>
            /// Specifies the propertyname for the  TtyTddPhone
            /// </summary>
            public const string TtyTddPhone = Namespaces.MapiPropTag + "x3a4b001f";

            /// <summary>
            /// Specifies the propertyname for the assistant phone
            /// </summary>
            public const string AssistantName = Namespaces.MapiPropTag + "x3a30001f";

            /// <summary>
            /// Specifies the propertyname for the birthday
            /// </summary>
            public const string Birthday = Namespaces.MapiPropTag + "x3a420040";

            /// <summary>
            /// Specifies the propertyname for the business homepage
            /// </summary>
            public const string BusinessHomepage = Namespaces.MapiPropTag + "x3a51001f";

            /// <summary>
            /// Specifies the propertyname for the children
            /// </summary>
            public const string Children = Namespaces.MapiPropTag + "x3a58101f";

            /// <summary>
            /// Specifies the propertyname for the companies
            /// </summary>
            public const string Companies = Namespaces.PropertySets.Common + "0x8539";

            /// <summary>
            /// Specifies the propertyname for the department
            /// </summary>
            public const string Department = Namespaces.MapiPropTag + "x3a18001f";

            /// <summary>
            /// Specifies the propertyname for the generation
            /// </summary>
            public const string Generation = Namespaces.MapiPropTag + "x3a05001f";

            /// <summary>
            /// Specifies the propertyname for the IM Address
            /// </summary>
            public const string IMAddress = Namespaces.PropertySets.Address + "0x8062";

            /// <summary>
            /// Specifies the propertyname for the manager
            /// </summary>
            public const string Manager = Namespaces.MapiPropTag + "x3a4e001f";

            /// <summary>
            /// Specifies the propertyname for the mileage
            /// </summary>
            public const string Mileage = Namespaces.PropertySets.Common + "0x8534";

            /// <summary>
            /// Specifies the propertyname for the office location
            /// </summary>
            public const string OfficeLocation = Namespaces.MapiPropTag + "x3a0d001f";

            /// <summary>
            /// Specifies the propertyname for the postal address index
            /// </summary>
            public const string PostalAddressIndex = Namespaces.PropertySets.Address + "0x8022";

            /// <summary>
            /// Specifies the propertyname for the profession
            /// </summary>
            public const string Profession = Namespaces.MapiPropTag + "x3a46001f";

            /// <summary>
            /// Specifies the propertyname for the spousename
            /// </summary>
            public const string SpouseName = Namespaces.MapiPropTag + "x3a48001f";

            /// <summary>
            /// Specifies the propertyname for the wedding anniversary
            /// </summary>
            public const string WeddingAnniversary = Namespaces.MapiPropTag + "x3a410040";
        }

        /// <summary>
        /// This class defines property names defined on appointment items
        /// </summary>
        public static class Appointment
        {
            /// <summary>
            /// Specifies the propertyname for the start time
            /// </summary>
            public const string Starttime = Namespaces.PropertySets.Appointment + "0x820d";

            /// <summary>
            /// Specifies the propertyname for the start time (MAPI property)
            /// </summary>
            public const string PRStartTime = Namespaces.MapiPropTag + "x600040";

            /// <summary>
            /// Specifies the propertyname for the end time
            /// </summary>
            public const string EndTime = Namespaces.PropertySets.Appointment + "0x820e";

            /// <summary>
            /// Specifies the propertyname for the end time (MAPI property)
            /// </summary>
            public const string PREndTime = Namespaces.MapiPropTag + "x610040";

            /// <summary>
            /// Specifies the propertyname for the flag indicating whether the appointment is
            /// an all-day event.
            /// </summary>
            public const string IsAllDavEvent = Namespaces.PropertySets.Appointment + "0x8215";

            /// <summary>
            /// Specifies the propertyname for the free busy status.
            /// </summary>
            public const string FreeBusyStatus = Namespaces.PropertySets.Appointment + "0x8205";

            /// <summary>
            /// Specifies the propertyname for the location
            /// </summary>
            public const string Location = Namespaces.PropertySets.Appointment + "0x8208";

            /// <summary>
            /// Specifies the propertyname for the When property (usage unknown)
            /// </summary>
            public const string When = Namespaces.PropertySets.Meeting + "0x22";

            /// <summary>
            /// Specifies the propertyname for the flag indicating whether the appointment is recurring
            /// </summary>
            public const string IsRecurring = Namespaces.PropertySets.Appointment + "0x8223";

            /// <summary>
            /// Specifies the propertyname for the flag indicating whether the meeting request for the
            /// appointment has been sent
            /// </summary>
            public const string MeetingRequestWasSent = Namespaces.PropertySets.Appointment + "0x8229";

            /// <summary>
            /// Specifies the propertyname for the flag indicating whether a response
            /// was requested
            /// </summary>
            public const string IsResponseRequested = Namespaces.MapiPropTag + "x63000b";

            /// <summary>
            /// Specifies the propertyname for the flag indicating whether the given 
            /// instance is an exception in a recurring appointment.
            /// </summary>
            public const string IsException = Namespaces.PropertySets.Meeting + "0xa";

            /// <summary>
            /// Specifies the propertyname for the response type.
            /// </summary>
            public const string ResponseType = Namespaces.PropertySets.Appointment + "0x8218";

            /// <summary>
            /// Specifies the propertyname for the sender of the meeting
            /// </summary>
            public const string SentDisplayName = Namespaces.MapiPropTag + "x0042001f";

            /// <summary>
            /// Specifies the propertyname for the email address of the sender
            /// </summary>
            public const string SentEmailAddress = Namespaces.MapiPropTag + "x0065001f";

            /// <summary>
            /// Specifies the propertyname for the address type of the senders email address
            /// </summary>
            public const string SentEmailAddressType = Namespaces.MapiPropTag + "x0064001f";

            /// <summary>
            /// Specifies the propertyname for the required attendees
            /// </summary>
            public const string RequiredAttendees = "urn:schemas:httpmail:to";

            /// <summary>
            /// Specifies the propertyname for the optional attendees
            /// </summary>
            public const string OptionalAttendees = "urn:schemas:httpmail:cc";

            /// <summary>
            /// Specifies the propertyname for the resources
            /// </summary>
            public const string Resources = "urn:schemas:httpmail:bcc";

            /// <summary>
            /// Specifies the propertyname for the duration
            /// </summary>
            public const string Duration = Namespaces.PropertySets.Appointment + "0x8213";

            /// <summary>
            /// Specifies the propertyname for the timezone
            /// </summary>
            public const string Timezone = Namespaces.PropertySets.Appointment + "0x8234";

            /// <summary>
            /// Specifies the propertyname for the reply time
            /// </summary>
            public const string AppointmentReplyTime = Namespaces.PropertySets.Appointment + "0x8220";

            /// <summary>
            /// Specifies the propertyname for the sequence number of the appointment
            /// </summary>
            public const string AppointmentSequenceNumber = Namespaces.PropertySets.Appointment + "0x8201";

            /// <summary>
            /// Specifies the propertyname for the appointment state.
            /// </summary>
            public const string AppointmentState = Namespaces.PropertySets.Appointment + "0x8217";

            /// <summary>
            /// Specifies the propertyname for the recurrence type
            /// </summary>
            public const string RecurrenceType = Namespaces.PropertySets.Appointment + "0x8231";

            /// <summary>
            /// Specifies the propertyname for the conference type
            /// </summary>
            public const string ConferenceType = Namespaces.PropertySets.Appointment + "0x8241";

            /// <summary>
            /// Specifies the propertyname for the flag indicating whether a new time
            /// can be proposed for the metting
            /// </summary>
            public const string DisallowNewTimeProposal = Namespaces.PropertySets.Appointment + "0x825a";

            /// <summary>
            /// Specifies the propertyname for the flag indicating whether the meeting instance
            /// is an online meeting.
            /// </summary>
            public const string IsOnlineMeeting = Namespaces.PropertySets.Appointment + "0x8240";

            /// <summary>
            /// Specifies the propertyname for the meeting workspace url
            /// </summary>
            public const string MeetingWorkspaceUrl = Namespaces.PropertySets.Appointment + "0x8209";

            /// <summary>
            /// Specifies the propertyname for the net show url
            /// </summary>
            public const string NetShowUrl = Namespaces.PropertySets.Appointment + "0x8248";

            /// <summary>
            /// Specifies the propertyname for the BLOB containing the recurrence info
            /// of the appointment
            /// </summary>
            public const string RecurrecenceBlob = Namespaces.PropertySets.Appointment + "0x8216";

            /// <summary>
            /// Specifies the propertyname for the instance type of the appointment.
            /// </summary>
            public const string InstanceType = "urn:schemas:calendar:instancetype";
        }

        /// <summary>
        /// This class defines property names used on mailbox objects
        /// </summary>
        public class Mailbox
        {
            /// <summary>
            /// Specifies the propertyname for the property containing the url of the default calendar folder.
            /// </summary>
            public const string CalendarFolderUrl = Namespaces.HttpMail + "calendar";

            /// <summary>
            /// Specifies the propertyname for the property containing the url of the default contact folder.
            /// </summary>
            public const string ContactsUrl = Namespaces.HttpMail + "contacts";

            /// <summary>
            /// Specifies the propertyname for the property containing the url of the default deleted items folder.
            /// </summary>
            public const string DeletedItemsFolderUrl = Namespaces.HttpMail + "deleteditems";

            /// <summary>
            /// Specifies the propertyname for the property containing the url of the default drafts folder.
            /// </summary>
            public const string DraftsFolderUrl = Namespaces.HttpMail + "drafts";

            /// <summary>
            /// Specifies the propertyname for the property containing the url of the default inbox folder.
            /// </summary>
            public const string InboxFolderUrl = Namespaces.HttpMail + "inbox";

            /// <summary>
            /// Specifies the propertyname for the property containing the url of the default junkmail folder.
            /// </summary>
            public const string JunkMailFolderUrl = Namespaces.HttpMail + "junkmail";

            /// <summary>
            /// Specifies the propertyname for the property containing the url of the default journal folder.
            /// </summary>
            public const string JournalFolderUrl = Namespaces.HttpMail + "journal";

            /// <summary>
            /// Specifies the propertyname for the property containing the url of the default notes folder.
            /// </summary>
            public const string NotesFolderUrl = Namespaces.HttpMail + "notes";

            /// <summary>
            /// Specifies the propertyname for the property containing the url of the default outbox folder.
            /// </summary>
            public const string OutboxFolderUrl = Namespaces.HttpMail + "outbox";

            /// <summary>
            /// Specifies the propertyname for the property containing the url of the default sendt items folder.
            /// </summary>
            public const string SentItemsFolderUrl = Namespaces.HttpMail + "sentitems";

            /// <summary>
            /// Specifies the propertyname for the property containing the url of the default tasks folder.
            /// </summary>
            public const string TasksFolderUrl = Namespaces.HttpMail + "tasks";

            /// <summary>
            /// Specifies the propertyname for the property containing the url of the default message submission folder.
            /// </summary>
            public const string MailSubmissionUrl = Namespaces.HttpMail + "sendmsg";

            /// <summary>
            /// Specifies the propertyname for the property containing the url of the mailbox root folder.
            /// </summary>
            public const string MailboxRootUrl = Namespaces.HttpMail + "msgfolderroots";
        }
    }
}